.. title:: Gallery

.. role:: header
   :class: h4


Gallery
=======

.. container:: lead

   A small selection of screenshots from the VisPy examples directory. More
   to come soon!


.. container:: row

   .. container:: col-sm-6 col-md-3

      .. container:: thumbnail

         .. image:: _static/screenshots/thumbnails/fireworks.png
            :width: 100%
            :class: img-rounded
            :target: https://github.com/vispy/vispy/blob/master/examples/demo/gloo/fireworks.py

         .. container:: caption

            :header:`Fireworks`

            This example demonstrates simulation of fireworks using point
            sprites and has been adapted from the `OpenGL ES 2.0 Programming
            Guide <http://opengles-book.com/es2/index.html>`_.

            .. raw:: html

               <a type="button" class="btn btn-primary btn-xs"
               href="https://github.com/vispy/vispy/blob/master/examples/demo/gloo/fireworks.py"/>
               <span class="fa fa-github"></span> Sources </a>


   .. container:: col-sm-6 col-md-3

      .. container:: thumbnail

         .. image:: _static/screenshots/thumbnails/galaxy.png
            :width: 100%
            :class: img-rounded
            :target: https://github.com/vispy/vispy/blob/master/examples/demo/gloo/galaxy/galaxy.py

         .. container:: caption

            :header:`Spiral galaxy`

            This is a simulation of a galaxy using the density wave theory as
            explained by Ingo Berg. All simulation details can be found on `his
            site <http://beltoforion.de/galaxy/galaxy_en.html>`_.

            .. raw:: html

               <a type="button" class="btn btn-primary btn-xs"
               href="https://github.com/vispy/vispy/blob/master/examples/demo/gloo/galaxy/galaxy.py"/>
               <span class="fa fa-github"></span> Sources
               </a>


   .. container:: col-sm-6 col-md-3

      .. container:: thumbnail

         .. image:: _static/screenshots/thumbnails/voronoi.png
            :width: 100%
            :class: img-rounded
            :target: https://github.com/vispy/vispy/blob/master/examples/demo/gloo/voronoi.py

         .. container:: caption

            :header:`Voronoi diagrams`

            This example shows dynamic Voronoi cells based on an `old technique
            <https://wwwx.cs.unc.edu/~geom/papers/documents/technicalreports/tr99011.pdf>`_
            where the hardware is used to compute the diagram using 3D occluded cones.

            .. raw:: html

               <a type="button" class="btn btn-primary btn-xs"
               href="https://github.com/vispy/vispy/blob/master/examples/demo/gloo/voronoi.py"/>
               <span class="fa fa-github"></span> Sources
               </a>


   .. container:: col-sm-6 col-md-3

      .. container:: thumbnail

         .. image:: _static/screenshots/thumbnails/high-frequency.png
            :width: 100%
            :class: img-rounded
            :target: https://github.com/vispy/vispy/blob/master/examples/demo/gloo/high_frequency.py

         .. container:: caption

            :header:`High-frequency signal`

            This example explains how to plot high-frequency functions by
            resampling the signal. More details on the `Syntopia
            <http://blog.hvidtfeldts.net/>`_ website and `Shadertoy
            <https://www.shadertoy.com/view/4sB3zz>`_

            .. raw:: html

               <a type="button" class="btn btn-primary btn-xs"
               href="https://github.com/vispy/vispy/blob/master/examples/demo/gloo/high_frequency.py">
               <span class="fa fa-github"></span> Sources </a>



   .. container:: col-sm-6 col-md-3

      .. container:: thumbnail

         .. image:: _static/screenshots/thumbnails/gloo-cloud.png
            :width: 100%
            :class: img-rounded
            :target: https://github.com/vispy/vispy/blob/master/examples/demo/gloo/cloud.py

         .. container:: caption

            :header:`Point cloud`

            This example shows a 3D cloud of a million anti-aliased and stroked
            points animated in real-time. Most of them are hidden though !

            .. raw:: html

               <a type="button" class="btn btn-primary btn-xs"
               href="https://github.com/vispy/vispy/blob/master/examples/demo/gloo/cloud.py"/>
               <span class="fa fa-github"></span> Sources
               </a>


   .. container:: col-sm-6 col-md-3

      .. container:: thumbnail

         .. image:: _static/screenshots/thumbnails/mandelbrot.png
            :width: 100%
            :class: img-rounded
            :target: https://github.com/vispy/vispy/blob/master/examples/demo/gloo/mandelbrot.py

         .. container:: caption

            :header:`Mandelbrot set`

            The mandatory Mandelbrot set computed in the GPU with single float
            precision even tough `double precision through emulation
            <https://www.thasler.org/blog/?p=93>`_ is possible.

            .. raw:: html

               <a type="button" class="btn btn-primary btn-xs"
               href="https://github.com/vispy/vispy/blob/master/examples/demo/gloo/mandelbrot.py"/>
               <span class="fa fa-github"></span> Sources
               </a>


   .. container:: col-sm-6 col-md-3

      .. container:: thumbnail

         .. image:: _static/screenshots/thumbnails/grayscott.png
            :width: 100%
            :class: img-rounded
            :target: https://github.com/vispy/vispy/blob/master/examples/demo/gloo/grayscott.py

         .. container:: caption

            :header:`Reaction Diffusion`

            This example simulates a Reaction diffusion using Gray-Scott model
            largely inspired from this `great site
            <http://mrob.com/pub/comp/xmorphia/>`_ that gives all the details.

            .. raw:: html

               <a type="button" class="btn btn-primary btn-xs"
               href="https://github.com/vispy/vispy/blob/master/examples/demo/gloo/grayscott.py"/>
               <span class="fa fa-github"></span> Sources
               </a>


   .. container:: col-sm-6 col-md-3

      .. container:: thumbnail

         .. image:: _static/screenshots/thumbnails/collection-custom-lines.png
            :width: 100%
            :class: img-rounded
            :target: https://github.com/vispy/vispy/blob/master/examples/demo/gloo/realtime_signals.py

         .. container:: caption

            :header:`Realtime signals`

            From an idea by Cyrille Rossant, this example shows 320 signals
            with 10,000 points each. Each signal can be zoomed in/out
            individually.

            .. raw:: html

               <a type="button" class="btn btn-primary btn-xs"
               href="https://github.com/vispy/vispy/blob/master/examples/demo/gloo/realtime_signals.py"/>
               <span class="fa fa-github"></span> Sources</a>
